Player = {}

function Player:load()
    self.x = love.graphics.getWidth() / 2 
    self.y = love.graphics.getHeight() / 2 - 62
    self.spriteSheet = love.graphics.newImage("Sprites/TheWizzl.png")
    self.speed = 400

    self.ground = self.y
    self.yVel = 0
    self.jump_height = -300
    self.gravity = -500

    self.grid = anim8.newGrid(32,32, self.spriteSheet:getWidth(), self.spriteSheet:getHeight())
    -- Animation Information
    self.anim = {}
    self.anim.idle = anim8.newAnimation(self.grid('1-4', 1), 0.2)
    self.anim.run = anim8.newAnimation(self.grid('8-11', 1), 0.1)
    self.anim.jump = anim8.newAnimation(self.grid(19, 1), 0.2)
    self.anim.fall = anim8.newAnimation(self.grid(20, 1), 0.2)
    self.anim.hide = anim8.newAnimation(self.grid('22-27', 1), 0.1)
    self.anim.hat = anim8.newAnimation(self.grid(28, 1), 0.1)
    self.anim.hatWalk = anim8.newAnimation(self.grid('29-33', 1), 0.1)
    self.anim.getUp = anim8.newAnimation(self.grid('35-38', 1), 0.1)


    self.anim.curr = self.anim.idle
    self.switch = 2
    self.crouch = false


end

function Player:update(dt)
   --[[ if love.keyboard.isDown('s') then
        self.crouch = true
        self.anim.curr = self.anim.hide
        --self.anim.curr = self.anim.hat
    end--]]
    function love.keypressed(key)
        if key == "escape" then
           love.event.quit()
        end
        if key == "s" then
            Player.anim.curr = Player.anim.hide
            Player.crouch = true
        end
        if key == "space" then 
            Player.crouch = false
        end
    
    end
    Player:move(dt)
    Player:jump(dt)
    self.anim.curr:update(dt)
end

function Player:draw()
    self.anim.curr:draw(self.spriteSheet, self.x, self.y, nil, self.switch, 2, 16)
end

function Player:move(dt)
    if love.keyboard.isDown("a") then
        self.switch = -2
        self.x = self.x - (self.speed * dt)
        if self.crouch == false then
            self.anim.curr = self.anim.run
        else
            self.anim.curr = self.anim.hatWalk
        end
    elseif love.keyboard.isDown("d") then
        self.switch = 2
        self.x = self.x + (self.speed * dt)
        if self.crouch == false then
            self.anim.curr = self.anim.run
        else
            self.anim.curr = self.anim.hatWalk
        end
    else
        if self.crouch == false then
            self.anim.curr = self.anim.idle
        else
            self.anim.curr = self.anim.hat
        end
    end

end

function Player:jump(dt)
    if self.crouch == false then    
        if love.keyboard.isDown("w") then
            if self.yVel == 0 then
                self.yVel = self.jump_height
            end
        end

        if self.yVel ~= 0 then
            self.y = self.y + self.yVel * dt
            self.yVel = self.yVel - self.gravity * dt
        end

        if self.y > self.ground then
            self.yVel = 0
            self.y = self.ground
        end

        if self.yVel < 0 then
            self.anim.curr = self.anim.jump
        elseif self.yVel > 0 then
            self.anim.curr = self.anim.fall
        end
    end
end

